@@ -21,7 +21,7 @@ reencode_file <- function(path, encoding) {
 }
 
 # These functions adapted from https://github.com/tidyverse/readr/blob/192cb1ca5c445e359f153d2259391e6d324fd0a2/R/source.R
-standardise_path <- function(path) {
+standardise_path <- function(path, user_env = caller_env(2)) {
   if (is.raw(path)) {
     return(list(rawConnection(path, "rb")))
   }
@@ -46,15 +46,18 @@ standardise_path <- function(path) {
     }
 
     if (any(grepl("\n", path))) {
-      lifecycle::deprecate_soft("1.5.0", "vroom(file = 'must use `I()` for literal data')",
-        details = glue::glue('
-
-          # Bad:
-          vroom("foo\\nbar\\n")
-
-          # Good:
-          vroom(I("foo\\nbar\\n"))
-        ')
+      lifecycle::deprecate_soft(
+        "1.5.0",
+        "vroom(file = 'must use `I()` for literal data')",
+        details = c(
+          " " = "",
+          " " = "# Bad:",
+          " " = 'vroom("X,Y\\n1.5,2.3\\n")',
+          " " = "",
+          " " = "# Good:",
+          " " = 'vroom(I("X,Y\\n1.5,2.3\\n"))'
+        ),
+        user_env = user_env
       )
       return(list(chr_to_file(path, envir = parent.frame())))
     }
@@ -77,7 +80,7 @@ standardise_one_path <- function (path, write = FALSE) {
     if (requireNamespace("curl", quietly = TRUE)) {
       con <- curl::curl(path)
     } else {
-      rlang::inform("`curl` package not installed, falling back to using `url()`")
+      inform("`curl` package not installed, falling back to using `url()`")
       con <- url(path)
     }
     ext <- tolower(tools::file_ext(path))
@@ -106,7 +109,7 @@ standardise_one_path <- function (path, write = FALSE) {
     path <- check_path(path)
   }
 
-  if (rlang::is_installed("archive")) {
+  if (is_installed("archive")) {
     formats <- archive_formats(p$extension)
     extension <- p$extension
     while(is.null(formats) && nzchar(extension)) {
@@ -244,7 +247,7 @@ zipfile <- function(path, open = "r") {
   file <- files$Name[[1]]
 
   if (nrow(files) > 1) {
-    rlang::inform(paste0("Multiple files in zip: reading '", file, "'"))
+    inform(paste0("Multiple files in zip: reading '", file, "'"))
   }
 
   unz(path, file, open = open)
