@@ -1,5 +1,9 @@
 #' Read a fixed width file into a tibble
 #'
+#' @details
+#' *Note*: `fwf_empty()` cannot take a R connection such as a URL as input, as
+#' this would result in reading from the connection twice. In these cases it is
+#' better to download the file first before reading.
 #' @inheritParams readr::read_fwf
 #' @inheritParams vroom
 #' @export
@@ -36,15 +40,15 @@ vroom_fwf <- function(file,
 
   verify_fwf_positions(col_positions)
 
-  if (!rlang::is_missing(altrep_opts)) {
-    lifecycle::deprecate_warn("1.1.0", "vroom_fwf(altrep_opts = )", "vroom_fwf(altrep = )")
+  if (!is_missing(altrep_opts)) {
+    deprecate_warn("1.1.0", "vroom_fwf(altrep_opts = )", "vroom_fwf(altrep = )")
     altrep <- altrep_opts
   }
 
   file <- standardise_path(file)
 
   if (!is_ascii_compatible(locale$encoding)) {
-    file <- reencode_path(file, locale$encoding)
+    file <- reencode_file(file, locale$encoding)
     locale$encoding <- "UTF-8"
   }
 
@@ -62,7 +66,7 @@ vroom_fwf <- function(file,
     guess_max <- -1
   }
 
-  col_select <- vroom_enquo(rlang::enquo(col_select))
+  col_select <- vroom_enquo(enquo(col_select))
 
   has_col_types <- !is.null(col_types)
 
